@@ -29,7 +29,7 @@ class BaseConfig(object):
                     elif isinstance(default_val, float):
                         v = float(v)
                     elif isinstance(default_val, bool):
-                        v = True if default_val in ['true', 'True', 'TRUE'] else False
+                        v = True if str(v).lower() == 'true' else False
                 except ValueError:
                     v = default_val
             setattr(self, k, v)
